From c83a430ab49be745395caf0242ba085a9c9b6c44 Mon Sep 17 00:00:00 2001
From: Alex Jurkiewicz <alex@jurkiewi.cz>
Date: Tue, 21 Aug 2012 17:30:13 +1000
Subject: [PATCH] Add manpage.

---
 Makefile      |    2 +
 configure     |    9 +++++
 doc/x264.1.md |   81 +++++++++++++++++++++++++++++++++++++++++
 x264.1        |  112 +++++++++++++++++++++++++++++++++++++++++++++++++++++++++
 4 files changed, 204 insertions(+), 0 deletions(-)
 create mode 100644 doc/x264.1.md
 create mode 100644 x264.1

diff --git a/Makefile b/Makefile
index 7a22c42..92a6269 100644
--- a/Makefile
+++ b/Makefile
@@ -240,6 +240,7 @@ distclean: clean
 install-cli: cli
 	install -d $(DESTDIR)$(bindir)
 	install x264$(EXE) $(DESTDIR)$(bindir)
+	install x264.1.gz $(DESTDIR)$(mandir)/man1
 
 install-lib-dev:
 	install -d $(DESTDIR)$(includedir)
@@ -266,6 +267,7 @@ endif
 uninstall:
 	rm -f $(DESTDIR)$(includedir)/x264.h $(DESTDIR)$(includedir)/x264_config.h $(DESTDIR)$(libdir)/libx264.a
 	rm -f $(DESTDIR)$(bindir)/x264$(EXE) $(DESTDIR)$(libdir)/pkgconfig/x264.pc
+	rm -f $(DESTDIR)$(mandir)/man1/x264.1.gz
 ifneq ($(IMPLIBNAME),)
 	rm -f $(DESTDIR)$(bindir)/$(SONAME) $(DESTDIR)$(libdir)/$(IMPLIBNAME)
 else ifneq ($(SONAME),)
diff --git a/configure b/configure
index 086b399..886d4e9 100755
--- a/configure
+++ b/configure
@@ -14,6 +14,7 @@ Standard options:
                            [PREFIX]
   --bindir=DIR             install binaries in DIR [EPREFIX/bin]
   --libdir=DIR             install libs in DIR [EPREFIX/lib]
+  --mandir=DIR             install manpages in DIR [EPREFIX/share/man]
   --includedir=DIR         install includes in DIR [PREFIX/include]
   --extra-asflags=EASFLAGS add EASFLAGS to ASFLAGS
   --extra-cflags=ECFLAGS   add ECFLAGS to CFLAGS
@@ -249,6 +250,7 @@ prefix='/usr/local'
 exec_prefix='${prefix}'
 bindir='${exec_prefix}/bin'
 libdir='${exec_prefix}/lib'
+mandir='${exec_prefix}/share/man'
 includedir='${prefix}/include'
 DEVNULL='/dev/null'
 
@@ -304,6 +306,9 @@ for opt do
         --libdir=*)
             libdir="$optarg"
             ;;
+	--mandir=*)
+	    mandir="$optarg"
+	    ;;
         --includedir=*)
             includedir="$optarg"
             ;;
@@ -1056,6 +1061,7 @@ prefix=$prefix
 exec_prefix=$exec_prefix
 bindir=$bindir
 libdir=$libdir
+mandir=$mandir
 includedir=$includedir
 ARCH=$ARCH
 SYS=$SYS
@@ -1149,6 +1155,9 @@ echo "CLI_LIBX264 = $CLI_LIBX264" >> config.mak
 
 ${SRCPATH}/version.sh "${SRCPATH}" >> x264_config.h
 
+rm -f x264.1.gz
+gzip -9 x264.1
+
 pclibs="-L$libdir -lx264 $libpthread"
 
 cat > x264.pc << EOF
diff --git a/doc/x264.1.md b/doc/x264.1.md
new file mode 100644
index 0000000..b36fb60
--- /dev/null
+++ b/doc/x264.1.md
@@ -0,0 +1,81 @@
+x264(1) -- h.264 video encoder
+==============================
+
+## SYNOPSIS
+
+`x264` --help<br>
+`x264` --fullhelp<br>
+`x264` \[options] [-o <outfile>] <infile> [<widthxheight>]
+
+## DESCRIPTION
+
+Encode video from a variety of input file formats to h.264 video in a variety of containers.
+
+## OPTIONS
+
+Help
+
+* `-h`, `--help`:
+    Display basic help.
+
+* `--fullhelp`:
+    Display help for all options.
+
+Input
+
+* <infile>:
+    Input file. Use `-` for stdin. Check `x264 --help` for information on supported input formats in your build.
+
+* <widthxheight>:
+    eg `640x480`. If your input is raw YUV, x264 must be told the resolution. Otherwise this option is not used.
+
+Preset System
+
+* `--profile` <profile>:
+    Limit the h.264 profile of the output stream. If you specify a profile, it overrides all other settings, guaranteeing a profile-compliant stream.
+
+    The default is unrestricted output.
+
+    Values available: `baseline`, `main`, `high`.
+
+* `--preset` <preset>:
+    Trade off compression efficiency against encoding time by changing encoder configuration. If you specify a preset, the changes it makes will be applied before anything except `--profile`.
+
+    Values available: `ultrafast`, `veryfast`, `faster`, `fast`, `medium` (default), `slow`, `slower`, `veryslow`, `placebo`.
+
+* `--tune` <tuning>[[,<tuning>],...]:
+    Tweak options to further optimize for your particular use-case. If you specify tunings, the changes will be applied after `--preset` but before all other parameters.
+
+    Values available: `film`, `animation`, `grain`, `psnr`, `ssim`, `fastdecode`, `zerolatency`.
+
+Common Options
+
+* `--output`, `-o` outfile:
+    Output filename (and format). Use `-` for stdout. Check `x264 --help` for information on supported output formats in your build. Unknown (or no) extension means raw format.
+* `--crf` <CRF>, `--bitrate` <kbits>:
+    Rate-control method. You can specify only one rate-control method. Default is `--crf 23`.
+
+    CRF is constant-quality, unknown-bitrate. Quality is specified as a real number in the range 0.0 - 51.0 (high to low quality respectively). Note: x264 built for >8 bit output depth uses a different scale.
+
+    Bitrate is constant-bitrate, unknown-quality. Multiple-pass encoding can significantly improve output quality. Bitrate is specified in kbit/secs.
+
+## EXAMPLES
+
+* Encode a file:
+    `x264` -o <outfile> <infile>
+
+* Encode raw YUV:
+    `x264 --fps 30000/1001> -o outfile infile 1280x720`
+
+* Two-pass encode with a bitrate of 1000kbps:
+    `x264 --pass 1 --bitrate 1000 -o /dev/null infile ; x264 --pass 2 --bitrate 1000 -o outfile infile`
+
+* Output lossless video
+    `x264 --qp 0 -o outfile infile`
+
+## SEE ALSO
+
+* x264 official homepage:
+    http://www.videolan.org/developers/x264.html
+* In-depth description of x264's settings:
+    http://mewiki.project357.com/wiki/X264_Settings
diff --git a/x264.1 b/x264.1
new file mode 100644
index 0000000..4dc873a
--- /dev/null
+++ b/x264.1
@@ -0,0 +1,112 @@
+.\" generated with Ronn/v0.7.3
+.\" http://github.com/rtomayko/ronn/tree/0.7.3
+.
+.TH "X264" "1" "" "" ""
+.
+.SH "NAME"
+\fBx264\fR \- h\.264 video encoder
+.
+.SH "SYNOPSIS"
+\fBx264\fR \-\-help
+.
+.br
+\fBx264\fR \-\-fullhelp
+.
+.br
+\fBx264\fR [options] [\-o \fIoutfile\fR] \fIinfile\fR [\fIwidthxheight\fR]
+.
+.SH "DESCRIPTION"
+Encode video from a variety of input file formats to h\.264 video in a variety of containers\.
+.
+.SH "OPTIONS"
+Help
+.
+.TP
+\fB\-h\fR, \fB\-\-help\fR
+Display basic help\.
+.
+.TP
+\fB\-\-fullhelp\fR
+Display help for all options\.
+.
+.P
+Input
+.
+.TP
+\fIinfile\fR
+Input file\. Use \fB\-\fR for stdin\. Check \fBx264 \-\-help\fR for information on supported input formats in your build\.
+.
+.TP
+\fIwidthxheight\fR
+eg \fB640x480\fR\. If your input is raw YUV, x264 must be told the resolution\. Otherwise this option is not used\.
+.
+.P
+Preset System
+.
+.TP
+\fB\-\-profile\fR \fIprofile\fR
+Limit the h\.264 profile of the output stream\. If you specify a profile, it overrides all other settings, guaranteeing a profile\-compliant stream\.
+.
+.IP
+The default is unrestricted output\.
+.
+.IP
+Values available: \fBbaseline\fR, \fBmain\fR, \fBhigh\fR\.
+.
+.TP
+\fB\-\-preset\fR \fIpreset\fR
+Trade off compression efficiency against encoding time by changing encoder configuration\. If you specify a preset, the changes it makes will be applied before anything except \fB\-\-profile\fR\.
+.
+.IP
+Values available: \fBultrafast\fR, \fBveryfast\fR, \fBfaster\fR, \fBfast\fR, \fBmedium\fR (default), \fBslow\fR, \fBslower\fR, \fBveryslow\fR, \fBplacebo\fR\.
+.
+.TP
+\fB\-\-tune\fR \fItuning\fR[[,\fItuning\fR],\.\.\.]
+Tweak options to further optimize for your particular use\-case\. If you specify tunings, the changes will be applied after \fB\-\-preset\fR but before all other parameters\.
+.
+.IP
+Values available: \fBfilm\fR, \fBanimation\fR, \fBgrain\fR, \fBpsnr\fR, \fBssim\fR, \fBfastdecode\fR, \fBzerolatency\fR\.
+.
+.P
+Common Options
+.
+.TP
+\fB\-\-output\fR, \fB\-o\fR outfile
+Output filename (and format)\. Use \fB\-\fR for stdout\. Check \fBx264 \-\-help\fR for information on supported output formats in your build\. Unknown (or no) extension means raw format\.
+.
+.TP
+\fB\-\-crf\fR \fICRF\fR, \fB\-\-bitrate\fR \fIkbits\fR
+Rate\-control method\. You can specify only one rate\-control method\. Default is \fB\-\-crf 23\fR\.
+.
+.IP
+CRF is constant\-quality, unknown\-bitrate\. Quality is specified as a real number in the range 0\.0 \- 51\.0 (high to low quality respectively)\. Note: x264 built for >8 bit output depth uses a different scale\.
+.
+.IP
+Bitrate is constant\-bitrate, unknown\-quality\. Multiple\-pass encoding can significantly improve output quality\. Bitrate is specified in kbit/secs\.
+.
+.SH "EXAMPLES"
+.
+.IP "\(bu" 4
+Encode a file: \fBx264\fR \-o \fIoutfile\fR \fIinfile\fR
+.
+.IP "\(bu" 4
+Encode raw YUV: \fBx264 \-\-fps 30000/1001> \-o outfile infile 1280x720\fR
+.
+.IP "\(bu" 4
+Two\-pass encode with a bitrate of 1000kbps: \fBx264 \-\-pass 1 \-\-bitrate 1000 \-o /dev/null infile ; x264 \-\-pass 2 \-\-bitrate 1000 \-o outfile infile\fR
+.
+.IP "\(bu" 4
+Output lossless video \fBx264 \-\-qp 0 \-o outfile infile\fR
+.
+.IP "" 0
+.
+.SH "SEE ALSO"
+.
+.TP
+x264 official homepage
+http://www\.videolan\.org/developers/x264\.html
+.
+.TP
+In\-depth description of x264\'s settings
+http://mewiki\.project357\.com/wiki/X264_Settings
+
-- 
1.7.2.5
